BlockDecomposition
==================

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: BlockDecomposition
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BlockDecomposition.forward_horizontally_stacked
      ~BlockDecomposition.forward_vertically_stacked
      ~BlockDecomposition.iter_extra_repr
      ~BlockDecomposition.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: forward_horizontally_stacked
   .. automethod:: forward_vertically_stacked
   .. automethod:: iter_extra_repr
   .. automethod:: reset_parameters
